@@ -36,11 +36,12 @@ class Metaschema(JSONSchema):
             value: Mapping[str, AnyJSONCompatible],
             core_vocabulary: Vocabulary,
             *default_vocabularies: Vocabulary,
+            **kwargs: Any,
     ):
         self.core_vocabulary: Vocabulary = core_vocabulary
         self.default_vocabularies: Tuple[Vocabulary, ...] = default_vocabularies
         self.kwclasses: Dict[str, KeywordClass] = {}
-        super().__init__(value, catalog=catalog, session='__meta__')
+        super().__init__(value, catalog=catalog, session='__meta__', **kwargs)
 
     def _bootstrap(self, value: Mapping[str, AnyJSONCompatible]) -> None:
         super()._bootstrap(value)
@@ -85,7 +86,7 @@ class Keyword:
             return True
 
         if instance.type == "number" and "integer" in types:
-            return instance.value == int(instance.value)
+            return instance.data == int(instance.data)
 
         return False
 
